@@ -1,38 +1,5 @@
 // kdelibs4.js of Serbian KDE translation
 
-// ------------------------------
-// Simplistic Cyrillic to Latin conversion:
-// - does not handle digraphs properly, e.g. ЉУБЉАНА→LjUBLjANA
-// - does not handle accented letters in NFC
-
-var _c2l_map_ = {
-    "а":"a", "б":"b", "в":"v", "г":"g", "д":"d", "ђ":"đ",
-    "е":"e", "ж":"ž", "з":"z", "и":"i", "ј":"j", "к":"k",
-    "л":"l", "љ":"lj","м":"m", "н":"n", "њ":"nj","о":"o",
-    "п":"p", "р":"r", "с":"s", "т":"t", "ћ":"ć", "у":"u",
-    "ф":"f", "х":"h", "ц":"c", "ч":"č", "џ":"dž","ш":"š",
-    "А":"A", "Б":"B", "В":"V", "Г":"G", "Д":"D", "Ђ":"Đ",
-    "Е":"E", "Ж":"Ž", "З":"Z", "И":"I", "Ј":"J", "К":"K",
-    "Л":"L", "Љ":"Lj","М":"M", "Н":"N", "Њ":"Nj","О":"O",
-    "П":"P", "Р":"R", "С":"S", "Т":"T", "Ћ":"Ć", "У":"U",
-    "Ф":"F", "Х":"H", "Ц":"C", "Ч":"Č", "Џ":"Dž","Ш":"Š",
-};
-
-function c2l (str)
-{
-    var strl = "";
-    for (var i = 0; i < str.length; i++) {
-        var c = str.charAt(i);
-        var cl = _c2l_map_[c];
-        if (cl) {
-            strl += cl;
-        } else {
-            strl += c;
-        }
-    }
-    return strl;
-}
-
 // ------------------------------
 // Property getter object contains the following data attributes:
 // - callname: the name of the getter call as exposed to PO files
@@ -117,12 +84,10 @@ function setcalls_prop (pgetr)
 {
     // Default call.
     Ts.setcall(pgetr.callname, pgetr.getprop, pgetr);
-    Ts.setcall(c2l(pgetr.callname), pgetr.getprop, pgetr);
     // "Open with $[callname %1]"
 
     // Form call.
     Ts.setcall(pgetr.callname + "/ф", pgetr.getform, pgetr);
-    Ts.setcall(c2l(pgetr.callname + "/ф"), pgetr.getform, pgetr);
     // "Open with $[callname/ф %1]"
 
     // The calls which capitalize the first letter of the value,
@@ -131,10 +96,8 @@ function setcalls_prop (pgetr)
     callname_uc = Ts.toUpperFirst(pgetr.callname);
     if (callname_uc != pgetr.callname) {
         Ts.setcall(callname_uc, pgetr.getprop_uc, pgetr);
-        Ts.setcall(c2l(callname_uc), pgetr.getprop_uc, pgetr);
         // "$[Callname %1] starting..."
         Ts.setcall(callname_uc + "/ф", pgetr.getform_uc, pgetr);
-        Ts.setcall(c2l(callname_uc + "/ф"), pgetr.getform_uc, pgetr);
         // "$[Callname/ф %1] starting..."
     }
 
@@ -196,13 +159,6 @@ function hasprop (phrase, pkey)
     return true;
 }
 
-// Set PO calls for given generic function.
-function setcalls (callname, callfunc)
-{
-    Ts.setcall(callname, callfunc);
-    Ts.setcall(c2l(callname), callfunc);
-}
-
 // ------------------------------
 // Predefined property getters.
 
@@ -339,7 +295,7 @@ function setprops_msgstrf (/*...*/)
     setprops(Ts.msgstrf(), arguments);
     throw Ts.fallback();
 }
-setcalls("својства", setprops_msgstrf);
+Ts.setcall("својства", setprops_msgstrf);
 // "$[callname prop1 value1 prop2 value2 ...]"
 
 // Manually set properties of the phrase given by the finalized msgstr
@@ -352,7 +308,7 @@ function setprops_msgstrf_e (/*...*/)
     setprops(Ts.msgstrf(), arguments);
     return "";
 }
-setcalls("својства/п", setprops_msgstrf_e);
+Ts.setcall("својства/п", setprops_msgstrf_e);
 // "$[callname prop1 value1 prop2 value2 ...]"
 
 // ------------------------------
@@ -370,7 +326,7 @@ function plural3 (n, form0, form1, form2)
     else
         return form2;
 }
-setcalls("множ", plural3);
+Ts.setcall("множ", plural3);
 // "...and %2 $[callname ^2 file fila files]"
 
 // ------------------------------
@@ -393,7 +349,7 @@ function select_by_gender (phrase, form_m, form_f, form_n)
         throw Ts.fallback();
     }
 }
-setcalls("по-роду", select_by_gender);
+Ts.setcall("по-роду", select_by_gender);
 // "Delete $[callname %1 this thisa thiso] %1?"
 
 // ------------------------------
@@ -412,13 +368,13 @@ function select_by_number (phrase, form_s, form_p)
         return form_s;
     }
 }
-setcalls("по-броју", select_by_number);
+Ts.setcall("по-броју", select_by_number);
 // "%1 $[callname %1 waalks waalk] by the river."
 
 // ------------------------------
 // Select one of six forms according to the gender and number of the phrase.
 function select_by_number_gender (phrase,
-                                  form_m, form_f, form_n, // singulars
+                                  form_ms, form_fs, form_ns, // singulars
                                   form_mp, form_fp, form_np) // plurals
 {
     // Select number (default to singular if not found).
@@ -430,10 +386,10 @@ function select_by_number_gender (phrase,
     if (number == "к") { // plural
         return select_by_gender(phrase, form_mp, form_fp, form_np);
     } else {
-        return select_by_gender(phrase, form_m, form_f, form_n);
+        return select_by_gender(phrase, form_ms, form_fs, form_ns);
     }
 }
-setcalls("по-роду-броју", select_by_number_gender);
+Ts.setcall("по-роду-броју", select_by_number_gender);
 // "Delete $[callname %1 this thisa thiso thees theesa theeso] %1?"
 
 // ------------------------------
@@ -443,7 +399,7 @@ function select_by_case_gender (gcase, gphrase, phrase) // plurals
     var gender = getprop(gphrase, "_род");
     return getprop(phrase, gcase + "-" + gender);
 }
-setcalls("по-падежу-роду", select_by_case_gender);
+Ts.setcall("по-падежу-роду", select_by_case_gender);
 // "Delete $[callname case %2 %1] [case %2]?"
 
 // ------------------------------
@@ -526,8 +482,7 @@ function apply_to_word (/* phrase, callname, ...args before word... */)
 
     return str;
 }
-setcalls("на-реч", apply_to_word);
-setcalls("на-ријеч", apply_to_word);
+Ts.setcall("на-реч", apply_to_word);
 // "Repeat until $[callname casecall %1], and on this date..."
 
 // ------------------------------
@@ -552,7 +507,7 @@ function decline_person_name (gcase, fullname)
 {
     return decline_person_name_base(gcase, fullname, false);
 }
-setcalls("именски", decline_person_name);
+Ts.setcall("именски", decline_person_name);
 // "You have invited $[callname case %1] to the party."
 
 // Decline person's name, return as-is if not possible.
@@ -560,7 +515,7 @@ function decline_person_name_nf (gcase, fullname)
 {
     return decline_person_name_base(gcase, fullname, true);
 }
-setcalls("именски/ф", decline_person_name_nf);
+Ts.setcall("именски/ф", decline_person_name_nf);
 // "You have invited $[callname case %1] to the party."
 
 // ------------------------------
@@ -589,7 +544,7 @@ function match_style_to_font (compstyle, gcase)
     }
     return final.substr(1); // to remove initial space
 }
-setcalls("стил-према-фонту", match_style_to_font);
+Ts.setcall("стил-према-фонту", match_style_to_font);
 
 // ------------------------------
 // Pick a phrase depending on a dynamic context field.
@@ -626,7 +581,7 @@ function select_by_context (/* ctxt_key,
 
     return phrase;
 }
-setcalls("по-контексту", select_by_context);
+Ts.setcall("по-контексту", select_by_context);
 
 // ------------------------------
 // Load property maps.
